@@ -60,7 +60,7 @@ impl Web3 {
         timeout: Option<Duration>,
         options: Vec<SendTxOption>,
     ) -> Result<Uint256, Web3Error> {
-        let own_address = eth_private_key.to_public_key()?;
+        let own_address = eth_private_key.to_address();
         let payload = encode_call(
             "approve(address,uint256)",
             &[target_contract.into(), Uint256::max_value().into()],
@@ -107,7 +107,7 @@ impl Web3 {
         wait_timeout: Option<Duration>,
         options: Vec<SendTxOption>,
     ) -> Result<Uint256, Web3Error> {
-        let sender_address = sender_private_key.to_public_key()?;
+        let sender_address = sender_private_key.to_address();
 
         // if the user sets a gas limit we should honor it, if they don't we
         // should add the default
